@@ -1,12 +1,12 @@
 import pytest
 from subprocess import check_output
-from unittest.mock import Mock
+from unittest.mock import patch, Mock
+from threading import Thread
 
 from ..mariadb_client import (
     MariaDBClient,
     ServerIsDownError,
     LoginError,
-    ContinuationPromptError,
 )
 from ..client_config import ClientConfig
 
@@ -44,20 +44,17 @@ def test_mariadb_client_raises_when_server_is_down():
 
 def test_mariadb_client_raises_when_credentials_are_wrong(mariadb_server):
     mocklog = Mock()
-    mockconfig = Mock()
 
-    # Start the server
-    mockconfig.server_bin.return_value = "mysqld"
-    mariadb_server(mocklog, mockconfig)
+    cfg = ClientConfig(mocklog, name="nonexistentcfg.json")  # default config
 
-    # Give the client a wrong port, simulate that MariaDB Server is down
-    mockconfig.client_bin.return_value = "mysql"
-    mockconfig.get_args.return_value = (
-        '--user=root --password="somewrongpass" --port=3306'
+    # Give the client wrong credentials
+    cfg.default_config.update(
+        {"user": "root", "password": "somewrongpassword", "port": 3306}
     )
 
-    client = MariaDBClient(mocklog, mockconfig)
-
+    # Start the server
+    mariadb_server(mocklog, cfg)
+    client = MariaDBClient(mocklog, cfg)
     with pytest.raises(LoginError):
         client.start()
 
@@ -67,7 +64,7 @@ def test_mariadb_client_raises_when_credentials_are_wrong(mariadb_server):
 
 def test_mariadb_client_run_statement(mariadb_server):
     mocklog = Mock()
-    cfg = ClientConfig(mocklog, name="nonexistentcfg.json")
+    cfg = ClientConfig(mocklog, name="nonexistentcfg.json")  # default config
     mariadb_server(mocklog, cfg)
 
     client = MariaDBClient(mocklog, cfg)
@@ -133,3 +130,35 @@ def test_input_lines_longer_than_max_cannon(mariadb_server):
 
     # Should not throw a TIMEOUT exception
     client.maria_repl.run_command(large_stmt, timeout=3)
+
+
+def test_cocurrent_execute_run_statement(mariadb_server):
+    # See https://pexpect.readthedocs.io/en/stable/api/pexpect.html#pexpect.spawn.send
+    # for an explanation on why this limitation exists
+    mocklog = Mock()
+    cfg = ClientConfig(mocklog, name="nonexistentcfg.json")
+    mariadb_server(mocklog, cfg)
+
+    client = MariaDBClient(mocklog, cfg)
+    client_2 = MariaDBClient(mocklog, cfg)
+
+    client.start()
+    client_2.start()
+
+    def client_run_statement():
+        result = client.run_statement("select 1;")
+        assert (
+            result == "<TABLE BORDER=1><TR><TH>1</TH></TR><TR><TD>1</TD></TR></TABLE>"
+        )
+
+    def client_2_run_statement():
+        result = client_2.run_statement("select 2;")
+        assert (
+            result == "<TABLE BORDER=1><TR><TH>2</TH></TR><TR><TD>2</TD></TR></TABLE>"
+        )
+
+    thread_1 = Thread(target=client_run_statement)
+    thread_2 = Thread(target=client_2_run_statement)
+    thread_1.start()
+    thread_2.start()
+    thread_1.join()
